Vxi11CreateLinkRequest class

Constructors

Vxi11CreateLinkRequest({required int clientId, bool lockDevice = false, int lockTimeoutMs = 0, required String device})
const

Properties

clientId int
final
device String
final
hashCode int
The hash code for this object.
no setterinherited
lockDevice bool
final
lockTimeoutMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited