Vxi11CreateLinkResponse class

Constructors

Vxi11CreateLinkResponse({required int errorCode, required int linkId, required int abortPort, required int maxRecvSize})
const
Vxi11CreateLinkResponse.decode(List<int> bytes)
factory

Properties

abortPort int
final
errorCode int
final
hashCode int
The hash code for this object.
no setterinherited
linkId int
final
maxRecvSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited