Vxi11ReadRequest class

Constructors

Vxi11ReadRequest({required int linkId, int requestSize = 1024, int ioTimeoutMs = 5000, int lockTimeoutMs = 0, int flags = 0, int termChar = 0x0A})
const

Properties

flags int
final
hashCode int
The hash code for this object.
no setterinherited
ioTimeoutMs int
final
linkId int
final
lockTimeoutMs int
final
requestSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termChar int
final

Methods

encode() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited