Vxi11ReadResponse class

Constructors

Vxi11ReadResponse({required int errorCode, required int reason, required Uint8List data})
const
Vxi11ReadResponse.decode(List<int> bytes)
factory

Properties

data Uint8List
final
errorCode int
final
hashCode int
The hash code for this object.
no setterinherited
reason int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited