Vxi11WriteResponse class

Constructors

Vxi11WriteResponse({required int errorCode, required int bytesWritten})
const
Vxi11WriteResponse.decode(List<int> bytes)
factory

Properties

bytesWritten int
final
errorCode int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited