XdrReader class

Constructors

XdrReader(List<int> bytes)

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
no setter
remaining int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBool() bool
readInt32() int
readOpaque() Uint8List
readString() String
readUint32() int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited