XdrWriter class

Constructors

XdrWriter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takeBytes() Uint8List
toString() String
A string representation of this object.
inherited
writeBool(bool v) → void
XDR bool is encoded as a 32-bit integer (0/1).
writeInt32(int v) → void
writeOpaque(List<int> bytes) → void
Variable-length opaque — length(uint32 BE) + bytes + 0..3 bytes of zero padding to align to 4-byte boundary.
writeString(String s) → void
XDR string — same wire form as opaque, defined separately for readability.
writeUint32(int v) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited