OncRpcReply class
Decoded ONC RPC reply.
Constructors
- OncRpcReply({required int xid, required int acceptStat, required bool denied, required Uint8List resultBytes})
-
const
Properties
- acceptStat → int
-
accept_statwhen the message was accepted (msg_accepted). -1 when the reply was denied — see denied.final - denied → bool
-
True when
reply_statwas MSG_DENIED.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- resultBytes → Uint8List
-
Procedure-specific result payload — only populated when
acceptStat == SUCCESS.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xid → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited