Vxi11WriteRequest class
Constructors
Properties
-
data
→ List<
int> -
final
- flags → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ioTimeoutMs → int
-
final
- linkId → int
-
final
- lockTimeoutMs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited